@@ -36,7 +36,7 @@ templates_path = ["_templates"]
 source_suffix = ".rst"
 master_doc = "index"
 # General information about the project.
-project = "CircuitPython bmp581 Library"
+project = "CircuitPython BMP581 Library"
 creation_year = "2023"
 current_year = str(datetime.datetime.now().year)
 year_duration = (
